@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2021 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ main (int argc, char **argv)
   struct mu_sockaddr *sa, *ap;
   int rc, i;
   char *node = NULL, *serv = NULL;
-  char *urlstr;
+  char *urlstr = NULL;
   
   mu_set_program_name (argv[0]);
 
