@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2005, 2007-2012, 2014-2017 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2021 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -255,7 +254,7 @@ imap4d_copy0 (imap4d_tokbuf_t tok, int isuid, char **err_text)
   status = mu_mailbox_create_from_record (&cmbox, record, mailbox_name);
   if (status == 0)
     {
-      /* It SHOULD NOT automatifcllly create the mailbox. */
+      /* It SHOULD NOT automatically create the mailbox. */
       status = mu_mailbox_open (cmbox, MU_STREAM_RDWR | mode);
       if (status == 0)
 	{
