@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2021 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -225,12 +225,11 @@ extern int imap4d_argc;
 extern char **imap4d_argv;
 extern jmp_buf child_jmp;
 extern struct mu_tls_config global_tls_conf;
-  
+extern int global_tls_mode;
+
 extern int test_mode;
 extern int silent_expunge;
 
-int tls_available;
-
 /* Input functions */
 extern mu_stream_t iostream;
 extern int  io_untagged_response (int, const char *, ...) MU_PRINTFLIKE(2,3);
@@ -250,7 +249,6 @@ extern int io_stream_completion_response (mu_stream_t str,
 void io_getline (char **pbuf, size_t *psize, size_t *pnbytes);
 void io_setio (int, int, struct mu_tls_config *);
 void io_flush (void);
-int io_wait_input (int);
 void io_enable_crlf (int);
 
 imap4d_tokbuf_t imap4d_tokbuf_init (void);
@@ -345,6 +343,7 @@ extern int  imap4d_select_status (void);
 extern int  imap4d_starttls (struct imap4d_session *,
 			     struct imap4d_command *, imap4d_tokbuf_t);
 int starttls_init (mu_m_server_t msrv);
+int starttls_server_check (struct imap4d_srv_config *cfg, char const *srvid);
 void tls_encryption_on (struct imap4d_session *);
 extern int  imap4d_status (struct imap4d_session *,
 			   struct imap4d_command *, imap4d_tokbuf_t);
@@ -381,7 +380,7 @@ extern void fetch_flags0 (const char *prefix, mu_message_t msg, int isuid);
 #define MKDIR_PERMISSIONS 0700
 int make_interdir (const char *name, int delim, int perms);
 
-/* Synchronisation on simultaneous access.  */
+/* Synchronization on simultaneous access.  */
 extern int imap4d_sync (void);
 extern void imap4d_sync_invalidate (void);
 extern int imap4d_sync_flags (size_t);
@@ -421,6 +420,10 @@ char *namespace_translate_name (char const *name,
 				struct namespace_prefix const **pfx);
 char *namespace_get_name (char const *name, mu_record_t *rec, int *mode);
 
+char *namespace_decode_delim (struct namespace_prefix const *pfx,
+			      char const *src);
+char *namespace_encode_delim (struct namespace_prefix const *pfx,
+			      char const *src);
 void translate_delim (char *dst, char const *src, int dst_delim, int src_delim);
 
 
@@ -467,9 +470,6 @@ int is_atom (const char *s);
 int util_isdelim (const char *str);
 int util_trim_nl (char *s, size_t len);
 
-void unistr_downcase (char const *input, char **output);
-int unistr_is_substring (char const *haystack, char const *needle);
-
 int set_xscript_level (int xlev);
 void xscript_declare_client_payload (size_t len);
 
