@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2005, 2007-2012, 2014-2017 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2021 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -119,7 +118,7 @@ imap4d_rename (struct imap4d_session *session,
   newname = imap4d_tokbuf_getarg (tok, IMAP4_ARG_2);
 
   if (mu_c_strcasecmp (newname, "INBOX") == 0)
-    return io_completion_response (command, RESP_NO, "Name Inbox is reservered");
+    return io_completion_response (command, RESP_NO, "Name Inbox is reserved");
 
   /* Allocates memory.  */
   newname = namespace_get_name (newname, &newrec, &mode);
