@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2000, 2005, 2007-2008, 2010-2012, 2014-2016 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999-2021 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -59,9 +58,9 @@ int mu_list_get_comparator (mu_list_t _list, mu_list_comparator_t *_pcmp);
 
   /* The destroy function is responsible for deallocating a list element.
      By default, it is not set. */
-typedef void (*mu_list_destroy_item_t) (void *);
+typedef mu_deallocator_t mu_list_destroy_item_t;
 
-  /* An often used destroy function.  It simply calls free(3) over the
+  /* An often used destroy function.  It simply calls free(3) on the
      _item. */
 void mu_list_free_item (void *_item);
 
@@ -114,10 +113,10 @@ int mu_list_insert   (mu_list_t _list, void *_item, void *_new_item,
                       int _insert_before);
   /* Remove _item from _list and deallocate any memory associated with it
      using the `destroy_item' method. */
-int mu_list_remove   (mu_list_t _list, void *_item);
+int mu_list_remove   (mu_list_t _list, const void *_item);
   /* A non-destructive version of mu_list_remove: removes the _item but does
      not deallocate it. */
-int mu_list_remove_nd  (mu_list_t _list, void *_item);
+int mu_list_remove_nd  (mu_list_t _list, const void *_item);
   /* Remove Nth element from the list. */
 int mu_list_remove_nth (mu_list_t list, size_t n);
   /* Remove Nth element from the list, non-destructive. */
@@ -137,7 +136,7 @@ int mu_list_pop (mu_list_t list, void **item);
   
 
   /* ************************************************* */
-  /* Interation over lists.                            */
+  /* Iteration over lists.                             */
   /* ************************************************* */
 
   /* Get iterator for this _list and return it in _pitr, if successful. */
@@ -154,8 +153,6 @@ int mu_list_foreach_dir (mu_list_t _list, int _dir, mu_list_action_t _action,
 			 void *_cbdata);
   /* Same as mu_list_foreach_dir with _dir==0. */
 int mu_list_foreach (mu_list_t _list, mu_list_action_t _action, void *_data);
-  /* A historical alias to the above. */
-int mu_list_do (mu_list_t, mu_list_action_t, void *) MU_DEPRECATED;
   
 
   /* ************************************************* */
@@ -304,7 +301,7 @@ typedef int (*mu_list_folder_t) (void *_item, void *_data,
        _data     -  call-specific data,
        _prev     -  on the first call, _init; on subsequent calls,
                     points to the value returned from the previous call
-		    to _fold in the _ret varialble,
+		    to _fold in the _ret variable,
        _ret      -  memory location where to store the result of this
                     call.
 
@@ -320,7 +317,7 @@ typedef int (*mu_list_folder_t) (void *_item, void *_data,
 
        0                   - success,
        EINVAL              - _list or _fold is NULL,
-       MU_ERR_OUT_PTR_NULL - _return_code is NULL
+       MU_ERR_OUT_PTR_NULL - _return_value is NULL
        other value         - non-zero value returned by _fold.
 
      The _fold function is not allowed to alter the list it is being applied
@@ -345,6 +342,9 @@ int mu_list_rfold (mu_list_t _list, mu_list_folder_t _fold, void *_data,
      first of them is less than the second, and +1 otherwise.
   */
 void mu_list_sort (mu_list_t _list, mu_list_comparator_t _comp);
+void mu_list_sort_r (mu_list_t _list,
+		     int (*_comp) (const void *, const void *, void *),
+		     void *_data);
   
 #ifdef __cplusplus
 }
