@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009, 2011-2012, 2014-2016 Free Software Foundation,
-   Inc.
+   Copyright (C) 2009-2021 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -34,6 +33,7 @@ struct _mu_file_stream
   int flags;
   char *filename;
   void *echo_state;
+  unsigned io_timeout;
 };
 
 int _mu_file_stream_create (struct _mu_file_stream **pstream, size_t size,
