@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2021 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -48,10 +48,14 @@ text_mime_cmp (const void *item, const void *ptr)
 {
   const struct mime_pattern *pat = item;
   mu_content_type_t ct = (mu_content_type_t) ptr;
-  if (mu_imap_wildmatch_ci (pat->pat_type, ct->type, 0) == 0
-      && (pat->pat_subtype == NULL
-	  || mu_imap_wildmatch (pat->pat_subtype, ct->subtype, '/') == 0))
-    return 0;
+  if (mu_imap_wildmatch_ci (pat->pat_type, ct->type, 0) == 0)
+    {
+      if (ct->subtype == NULL)
+	return pat->pat_subtype != NULL;
+      if (pat->pat_subtype == NULL
+	  || mu_imap_wildmatch (pat->pat_subtype, ct->subtype, '/') == 0)
+	return 0;
+    }
   return 1;
 } 
 
@@ -211,10 +215,12 @@ message_body_stream (mu_message_t msg, int unix_header, char const *charset,
       return rc;
     }
 
-  rc = mu_content_type_parse (buf, NULL, &ct);
+  rc = mu_content_type_parse_ext (buf, NULL,
+				  MU_CONTENT_TYPE_RELAXED |
+				  MU_CONTENT_TYPE_PARAM, &ct);
   if (rc)
     {
-      mu_diag_funcall (MU_DIAG_ERROR, "mu_content_type_parse", buf, rc);
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_content_type_parse_ext", buf, rc);
       free (buf);
       return rc;
     }
@@ -262,6 +268,10 @@ message_body_stream (mu_message_t msg, int unix_header, char const *charset,
 	  mu_stream_unref (stream);
 	  stream = d_stream;
 	}
+      else if (rc == MU_ERR_NOENT)
+	{
+	  mu_error ("unknown encoding: %s", encoding);
+	}
       else
 	{
 	  mu_diag_funcall (MU_DIAG_ERROR, "mu_filter_create", encoding, rc);
