@@ -94,7 +94,7 @@ mu_folder_create_from_record (mu_folder_t *pfolder, mu_url_t url,
 	    {
 	      folder->url = url;
 	      folder->is_local = record->flags & MU_RECORD_LOCAL;
-	      /* Initialize the internal foilder lock, now so the
+	      /* Initialize the internal folder lock, now so the
 		 concrete folder could use it.  */
 	      status = mu_monitor_create (&folder->monitor, 0, folder);
 	      if (status == 0)
@@ -392,6 +392,7 @@ mu_folder_enumerate (mu_folder_t folder, const char *name,
 	  status = mu_list_create (&scn.result);
 	  if (status)
 	    return status;
+	  mu_list_set_destroy_item (scn.result, mu_list_response_free);
 	}
       status = mu_folder_scan (folder, &scn);
       if (status == 0)
