@@ -144,13 +144,6 @@ extern int yydebug;
     NUMBER = 263
   };
 #endif
-/* Tokens.  */
-#define TYPE 258
-#define IDENT 259
-#define REGEXP 260
-#define HEADER 261
-#define BODY 262
-#define NUMBER 263
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
@@ -164,7 +157,7 @@ union YYSTYPE
   int type;
   msgset_t *mset;
 
-#line 168 "msgset.c" /* yacc.c:355  */
+#line 161 "msgset.c" /* yacc.c:355  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -181,7 +174,7 @@ int yyparse (void);
 
 /* Copy the second part of user declarations.  */
 
-#line 185 "msgset.c" /* yacc.c:358  */
+#line 178 "msgset.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -1300,7 +1293,7 @@ yyreduce:
     {
 	     result = msgset_make_1 (get_cursor ());
 	   }
-#line 1304 "msgset.c" /* yacc.c:1646  */
+#line 1297 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 3:
@@ -1308,7 +1301,7 @@ yyreduce:
     {
 	     result = msgset_make_1 (get_cursor ());
 	   }
-#line 1312 "msgset.c" /* yacc.c:1646  */
+#line 1305 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 4:
@@ -1316,7 +1309,7 @@ yyreduce:
     {
 	     result = (yyvsp[0].mset);
 	   }
-#line 1320 "msgset.c" /* yacc.c:1646  */
+#line 1313 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 5:
@@ -1324,7 +1317,7 @@ yyreduce:
     {
 	     result = msgset_select (select_deleted, NULL, 0, 1);
 	   }
-#line 1328 "msgset.c" /* yacc.c:1646  */
+#line 1321 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 6:
@@ -1332,7 +1325,7 @@ yyreduce:
     {
 	     result = msgset_select (select_deleted, NULL, 1, 1);
 	   }
-#line 1336 "msgset.c" /* yacc.c:1646  */
+#line 1329 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 7:
@@ -1340,7 +1333,7 @@ yyreduce:
     {
 	     result = msgset_select (select_deleted, NULL, 0, total);
 	   }
-#line 1344 "msgset.c" /* yacc.c:1646  */
+#line 1337 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 8:
@@ -1348,7 +1341,7 @@ yyreduce:
     {
 	     result = msgset_select (select_deleted, NULL, 1, 1);
 	   }
-#line 1352 "msgset.c" /* yacc.c:1646  */
+#line 1345 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 9:
@@ -1356,7 +1349,7 @@ yyreduce:
     {
 	     result = msgset_select (select_deleted, NULL, 0, 1);
 	   }
-#line 1360 "msgset.c" /* yacc.c:1646  */
+#line 1353 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 11:
@@ -1364,7 +1357,7 @@ yyreduce:
     {
 	     (yyval.mset) = msgset_append ((yyvsp[-2].mset), (yyvsp[0].mset));
 	   }
-#line 1368 "msgset.c" /* yacc.c:1646  */
+#line 1361 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 12:
@@ -1372,7 +1365,7 @@ yyreduce:
     {
 	     (yyval.mset) = msgset_append ((yyvsp[-1].mset), (yyvsp[0].mset));
 	   }
-#line 1376 "msgset.c" /* yacc.c:1646  */
+#line 1369 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 13:
@@ -1382,7 +1375,7 @@ yyreduce:
 	     if (check_set (&(yyval.mset)))
 	       YYABORT;
 	   }
-#line 1386 "msgset.c" /* yacc.c:1646  */
+#line 1379 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 14:
@@ -1390,7 +1383,7 @@ yyreduce:
     {
 	     (yyval.mset) = (yyvsp[-1].mset);
 	   }
-#line 1394 "msgset.c" /* yacc.c:1646  */
+#line 1387 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 15:
@@ -1398,7 +1391,7 @@ yyreduce:
     {
 	     (yyval.mset) = msgset_negate ((yyvsp[0].mset));
 	   }
-#line 1402 "msgset.c" /* yacc.c:1646  */
+#line 1395 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 17:
@@ -1408,7 +1401,7 @@ yyreduce:
 	     msgset_free ((yyvsp[-2].mset));
 	     msgset_free ((yyvsp[0].mset));
 	   }
-#line 1412 "msgset.c" /* yacc.c:1646  */
+#line 1405 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 18:
@@ -1418,7 +1411,7 @@ yyreduce:
 	     msgset_free ((yyvsp[-3].mset));
 	     msgset_free ((yyvsp[-1].mset));
 	   }
-#line 1422 "msgset.c" /* yacc.c:1646  */
+#line 1415 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 20:
@@ -1437,7 +1430,7 @@ yyreduce:
 		 YYERROR;
 	       }
 	   }
-#line 1441 "msgset.c" /* yacc.c:1646  */
+#line 1434 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 21:
@@ -1450,7 +1443,7 @@ yyreduce:
 		 YYERROR;
 	       }
 	   }
-#line 1454 "msgset.c" /* yacc.c:1646  */
+#line 1447 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 22:
@@ -1469,7 +1462,7 @@ yyreduce:
 		 YYERROR;
 	       }
 	   }
-#line 1473 "msgset.c" /* yacc.c:1646  */
+#line 1466 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 23:
@@ -1482,7 +1475,7 @@ yyreduce:
 		 YYERROR;
 	       }
 	   }
-#line 1486 "msgset.c" /* yacc.c:1646  */
+#line 1479 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 24:
@@ -1490,7 +1483,7 @@ yyreduce:
     {
 	     (yyval.string) = NULL;
 	   }
-#line 1494 "msgset.c" /* yacc.c:1646  */
+#line 1487 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 25:
@@ -1498,7 +1491,7 @@ yyreduce:
     {
 	     (yyval.string) = (yyvsp[0].string);
 	   }
-#line 1502 "msgset.c" /* yacc.c:1646  */
+#line 1495 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 27:
@@ -1506,7 +1499,7 @@ yyreduce:
     {
 	     (yyval.mset) = msgset_append ((yyvsp[-2].mset), (yyvsp[0].mset));
 	   }
-#line 1510 "msgset.c" /* yacc.c:1646  */
+#line 1503 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 28:
@@ -1514,7 +1507,7 @@ yyreduce:
     {
 	     (yyval.mset) = msgset_append ((yyvsp[-1].mset), (yyvsp[0].mset));
 	   }
-#line 1518 "msgset.c" /* yacc.c:1646  */
+#line 1511 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 30:
@@ -1532,7 +1525,7 @@ yyreduce:
 		 msgset_append ((yyval.mset), (yyvsp[0].mset));
 	       }
 	   }
-#line 1536 "msgset.c" /* yacc.c:1646  */
+#line 1529 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 31:
@@ -1540,14 +1533,14 @@ yyreduce:
     {
 	     (yyval.mset) = msgset_range ((yyvsp[-2].number), total);
 	   }
-#line 1544 "msgset.c" /* yacc.c:1646  */
+#line 1537 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 32:
 #line 244 "msgset.y" /* yacc.c:1646  */
     {
 	   }
-#line 1551 "msgset.c" /* yacc.c:1646  */
+#line 1544 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 33:
@@ -1557,7 +1550,7 @@ yyreduce:
 	     msgset_free ((yyvsp[-2].mset));
 	     msgset_free ((yyvsp[0].mset));
 	   }
-#line 1561 "msgset.c" /* yacc.c:1646  */
+#line 1554 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 34:
@@ -1567,7 +1560,7 @@ yyreduce:
 	     msgset_free ((yyvsp[-3].mset));
 	     msgset_free ((yyvsp[-1].mset));
 	   }
-#line 1571 "msgset.c" /* yacc.c:1646  */
+#line 1564 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 35:
@@ -1575,7 +1568,7 @@ yyreduce:
     {
 	     (yyval.mset) = msgset_make_1 ((yyvsp[0].number));
 	   }
-#line 1579 "msgset.c" /* yacc.c:1646  */
+#line 1572 "msgset.c" /* yacc.c:1646  */
     break;
 
   case 36:
@@ -1583,11 +1576,11 @@ yyreduce:
     {
 	     (yyval.mset) = (yyvsp[-1].mset);
 	   }
-#line 1587 "msgset.c" /* yacc.c:1646  */
+#line 1580 "msgset.c" /* yacc.c:1646  */
     break;
 
 
-#line 1591 "msgset.c" /* yacc.c:1646  */
+#line 1584 "msgset.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
