@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2010-2019 Free Software Foundation, Inc.
+   Copyright (C) 2010-2021 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -521,12 +521,15 @@ com_connect (int argc, char **argv)
 	  if (tls)
 	    {
 	      mu_stream_t tlsstream;
-	      
-	      status = mu_tls_client_stream_create (&tlsstream, tcp, tcp, 0);
+
+	      status = mu_tlsfd_stream_convert (&tlsstream, tcp, NULL,
+						MU_TLS_CLIENT);
 	      mu_stream_unref (tcp);
 	      if (status)
 		{
-		  mu_error (_("cannot create TLS stream: %s"),
+		  if (status == MU_ERR_TRANSPORT_SET)
+		    mu_stream_destroy (&tlsstream);
+		  mu_error ("cannot create TLS stream: %s",
 			    mu_strerror (status));
 		  return 0;
 		}
@@ -534,7 +537,8 @@ com_connect (int argc, char **argv)
 	    }
 #endif
 	  mu_imap_set_carrier (imap, tcp);
-
+	  mu_stream_unref (tcp);
+	  
 	  if (QRY_VERBOSE ())
 	    {
 	      imap_set_verbose ();
@@ -1298,6 +1302,8 @@ struct mutool_command imap_comtab[] = {
 int
 main (int argc, char **argv)
 {
+  mu_set_program_name (argv[0]);
+  
   mu_action_getopt (&argc, &argv, NULL, imap_docstring, NULL);
 
   if (argc)
