@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2019 Free Software Foundation, Inc.
+   Copyright (C) 2009-2021 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
 #include "pop3d.h"
 
-struct mu_tls_config global_tls_conf;
+struct mu_tls_config global_tls_conf = { .handshake_timeout = 10 };
 int global_tls_mode;
 int global_conf_status = -1;
 
@@ -174,7 +174,7 @@ static char *error_table[] = {
   [ERR_BAD_CMD]     =   "Invalid command",
   [ERR_MBOX_LOCK]   =   "[IN-USE] Mailbox in use",
   [ERR_TOO_LONG]    =   "Argument too long",
-  [ERR_NO_MEM]      =   "Out of memory] =quitting",
+  [ERR_NO_MEM]      =   "Out of memory, quitting",
   [ERR_SIGNAL]      =   "Quitting on signal",
   [ERR_FILE]        =   "Some deleted messages not removed",
   [ERR_NO_IFILE]    =   "No input stream",
